@@ -1,19 +1,19 @@
 /* Wrapper arpund system calls to provide cancelation points.
-   Copyright (C) 1996,1997,1998,1999,2000,2001 Free Software Foundation, Inc.
+   Copyright (C) 1996-1999,2000-2002 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1996.
 
    The GNU C Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   modify it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of the
    License, or (at your option) any later version.
 
    The GNU C Library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public
+   You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; see the file COPYING.LIB.  If not,
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
@@ -69,6 +69,8 @@ name param_list								      \
   return result;							      \
 }
 
+#define PROMOTE_INTEGRAL_TYPE(type) __typeof__ ((type) 0 + 0)
+
 
 /* close(2).  */
 CANCELABLE_SYSCALL (int, close, (int fd), (fd))
@@ -105,17 +107,22 @@ CANCELABLE_SYSCALL (int, msync, (__ptr_t addr, size_t length, int flags),
 CANCELABLE_SYSCALL (int, nanosleep, (const struct timespec *requested_time,
 				     struct timespec *remaining),
 		    (requested_time, remaining))
+strong_alias (nanosleep, __nanosleep)
 
 
 /* open(2).  */
 CANCELABLE_SYSCALL_VA (int, open, (const char *pathname, int flags, ...),
-		       (pathname, flags, va_arg (ap, mode_t)), flags)
+		       (pathname, flags,
+			va_arg (ap, PROMOTE_INTEGRAL_TYPE (mode_t))),
+		       flags)
 strong_alias (open, __open)
 
 
 /* open64(3).  */
 CANCELABLE_SYSCALL_VA (int, open64, (const char *pathname, int flags, ...),
-		       (pathname, flags, va_arg (ap, mode_t)), flags)
+		       (pathname, flags,
+			va_arg (ap, PROMOTE_INTEGRAL_TYPE (mode_t))),
+		       flags)
 strong_alias (open64, __open64)
 
 
